"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_1 = require("@prisma/client");
const src_1 = require("../src");
const fixtures_1 = require("./fixtures");
describe('prisma-relay-cursor-connection', () => {
    let client;
    beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
        client = new client_1.PrismaClient();
        yield client.todo.deleteMany({});
        for (let i = 0; i !== fixtures_1.TODO_FIXTURES.length; i++) {
            yield client.todo.create({ data: fixtures_1.TODO_FIXTURES[i] });
        }
    }));
    afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.disconnect();
    }));
    it('returns all TODOs with the base client (sanity check)', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.todo.findMany({});
        expect(result).toEqual(fixtures_1.TODO_FIXTURES);
    }));
    it('returns the paginated TODOs with the base client (sanity check)', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.todo.findMany({ cursor: { id: 'id_05' }, take: 5, skip: 1 });
        expect(result).toMatchSnapshot();
    }));
    it('returns all TODOs', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 20 });
        expect(result.pageInfo).toMatchSnapshot();
        expect(result.edges.map((edge) => edge.node)).toEqual(fixtures_1.TODO_FIXTURES);
    }));
    it('returns the first 5 TODOs', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5 });
        expect(result).toMatchSnapshot();
    }));
    it('returns the first 5 completed TODOs', () => __awaiter(void 0, void 0, void 0, function* () {
        const baseArgs = {
            select: { id: true, isCompleted: true },
            where: { isCompleted: true },
        };
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(Object.assign(Object.assign({}, args), baseArgs)), () => client.todo.count(baseArgs), { first: 5 });
        expect(result).toMatchSnapshot();
        result.edges[0].node.isCompleted;
        result.edges[0].node.isCompletedd;
        result.edges[0].node.text;
    }));
    it('returns the first 5 TODOs after the 5th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_05' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the first 5 TODOs after the 15th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_15' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the first 5 TODOs after the 16th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_16' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the first 5 TODOs after the 20th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_20' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the last 5 TODOs', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5 });
        expect(result).toMatchSnapshot();
    }));
    it('returns the last 5 TODOs before the 5th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5, before: 'id_05' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the last 5 TODOs before the 6th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5, before: 'id_06' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the last 5 TODOs before the 16th todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5, before: 'id_16' });
        expect(result).toMatchSnapshot();
    }));
    it('returns the last 5 TODOs before the 1st todo', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5, before: 'id_01' });
        expect(result).toMatchSnapshot();
    }));
    it('errors for invalid arguments (negative first)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: -5 });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (negative last)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: -5 });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (no first & no last)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), {});
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (both first & last)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, last: 5 });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (both after & before)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { after: 'id_05', before: 'id_15' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (both after & before with first)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_05', before: 'id_15' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (after without first)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { after: 'id_05' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (before without last)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { before: 'id_15' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (after with last)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { last: 5, after: 'id_05' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (before with first)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, before: 'id_15' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
    it('errors for invalid arguments (kitchensink)', () => __awaiter(void 0, void 0, void 0, function* () {
        let error;
        try {
            yield src_1.findManyCursorConnection((args) => client.todo.findMany(args), () => client.todo.count(), { first: 5, after: 'id_05', last: 5, before: 'id_15' });
        }
        catch (err) {
            error = err;
        }
        expect(error).toMatchSnapshot();
    }));
});
//# sourceMappingURL=index.spec.js.map